==> activity-center-api-1.7.20-20170921.034250-1-sources.jar: cn/com/duiba/activity/center/api/dto/statistics/SignActivityStatDto.java <==
package cn.com.duiba.activity.center.api.dto.statistics;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by sty on 8/20/17.
 */
public class SignActivityStatDto implements Serializable {

    private static final long serialVersionUID = -7670147945117957549L;

    /**
     * id
     */
    private Long id;
    /**
     * 当前日期
     */
    private Date curDay;
    /**
     * appId
     */
    private Long appId;
    /**
     * app名字
     */
    private String appName;
    /**
     * 签到活动id
     */
    private Long signId;
    /**
     * 签到活动名称
     */
    private String signName;
    /**
     *签到页面 pv
     */
    private Long pv;
    /**
     * 签到页面uv
     */
    private Long uv;
    /**
     * 成功签到的uv
     */
    private Long sucSignUv;
    /**
     * 签到失败的uv
     */
    private Long failSignUv;
    /**
     * 签到新用户
     */
    private Long newUser;
    private Date gmtCreate;
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Date getCurDay() {
        return curDay;
    }

    public void setCurDay(Date curDay) {
        this.curDay = curDay;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public Long getSignId() {
        return signId;
    }

    public void setSignId(Long signId) {
        this.signId = signId;
    }

    public String getSignName() {
        return signName;
    }

    public void setSignName(String signName) {
        this.signName = signName;
    }

    public Long getPv() {
        return pv;
    }

    public void setPv(Long pv) {
        this.pv = pv;
    }

    public Long getUv() {
        return uv;
    }

    public void setUv(Long uv) {
        this.uv = uv;
    }

    public Long getSucSignUv() {
        return sucSignUv;
    }

    public void setSucSignUv(Long sucSignUv) {
        this.sucSignUv = sucSignUv;
    }

    public Long getFailSignUv() {
        return failSignUv;
    }

    public void setFailSignUv(Long failSignUv) {
        this.failSignUv = failSignUv;
    }

    public Long getNewUser() {
        return newUser;
    }

    public void setNewUser(Long newUser) {
        this.newUser = newUser;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> activity-center-api-3.6.32-sources.jar: cn/com/duiba/activity/center/api/dto/statistics/SignActivityStatDto.java <==
package cn.com.duiba.activity.center.api.dto.statistics;

import java.io.Serializable;
import java.util.Date;

/**
 * Created by sty on 8/20/17.
 */
public class SignActivityStatDto implements Serializable {

    private static final long serialVersionUID = -7670147945117957549L;

    /**
     * id
     */
    private Long id;
    /**
     * 当前日期
     */
    private Date curDay;
    /**
     * appId
     */
    private Long appId;
    /**
     * app名字
     */
    private String appName;
    /**
     * 签到活动id
     */
    private Long signId;
    /**
     * 签到活动名称
     */
    private String signName;
    /**
     *签到页面 pv
     */
    private Long pv;
    /**
     * 签到页面uv
     */
    private Long uv;
    /**
     * 成功签到的uv
     */
    private Long sucSignUv;
    /**
     * 签到失败的uv
     */
    private Long failSignUv;
    /**
     * 签到新用户
     */
    private Long newUser;
    /**
     * 3日留存
     */
    private Long liucunThree;
    /**
     * 7日留存
     */
    private Long liucunSeven;
    /**
     * 页面次日留存
     */
    private Long pageLiucun;
    /**
     * 签到成功次日留存
     */
    private Long signLiucun;
    /**
     * 链接点击PV
     */
    private Long urlPv;
    /**
     * 链接点击UV
     */
    private Long urlUv;
    /**
     * 补签UV
     */
    private Long resignUv;
    private Date gmtCreate;
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Date getCurDay() {
        return curDay;
    }

    public void setCurDay(Date curDay) {
        this.curDay = curDay;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public Long getSignId() {
        return signId;
    }

    public void setSignId(Long signId) {
        this.signId = signId;
    }

    public String getSignName() {
        return signName;
    }

    public void setSignName(String signName) {
        this.signName = signName;
    }

    public Long getPv() {
        return pv;
    }

    public void setPv(Long pv) {
        this.pv = pv;
    }

    public Long getUv() {
        return uv;
    }

    public void setUv(Long uv) {
        this.uv = uv;
    }

    public Long getSucSignUv() {
        return sucSignUv;
    }

    public void setSucSignUv(Long sucSignUv) {
        this.sucSignUv = sucSignUv;
    }

    public Long getFailSignUv() {
        return failSignUv;
    }

    public void setFailSignUv(Long failSignUv) {
        this.failSignUv = failSignUv;
    }

    public Long getNewUser() {
        return newUser;
    }

    public void setNewUser(Long newUser) {
        this.newUser = newUser;
    }

    public Long getLiucunThree() {
        return liucunThree;
    }

    public void setLiucunThree(Long liucunThree) {
        this.liucunThree = liucunThree;
    }

    public Long getLiucunSeven() {
        return liucunSeven;
    }

    public void setLiucunSeven(Long liucunSeven) {
        this.liucunSeven = liucunSeven;
    }

    public Long getPageLiucun() {
        return pageLiucun;
    }

    public void setPageLiucun(Long pageLiucun) {
        this.pageLiucun = pageLiucun;
    }

    public Long getSignLiucun() {
        return signLiucun;
    }

    public void setSignLiucun(Long signLiucun) {
        this.signLiucun = signLiucun;
    }

    public Long getUrlPv() {
        return urlPv;
    }

    public void setUrlPv(Long urlPv) {
        this.urlPv = urlPv;
    }

    public Long getUrlUv() {
        return urlUv;
    }

    public void setUrlUv(Long urlUv) {
        this.urlUv = urlUv;
    }

    public Long getResignUv() {
        return resignUv;
    }

    public void setResignUv(Long resignUv) {
        this.resignUv = resignUv;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}
